@@ -1,10 +1,11 @@
-from netbox_config_backup.models.backups import Backup, BackupCommit, BackupObject, BackupCommitTreeChange
+from netbox_config_backup.models.backups import Backup, BackupCommit, BackupFile, BackupObject, BackupCommitTreeChange
 from netbox_config_backup.models.jobs import BackupJob
 
 
 __all__ = (
     'Backup',
     'BackupCommit',
+    'BackupFile',
     'BackupObject',
     'BackupCommitTreeChange',
     'BackupJob',
